@@ -19,15 +19,11 @@ from grafana_dashboards.schema.row import Row
 
 class Dashboard(object):
 
-    def validate(self, data):
+    def get_schema(self):
         dashboard = {
             v.Required('title'): v.All(str, v.Length(min=1)),
             v.Optional('id'): int,
         }
         rows = Row().get_schema()
         dashboard.update(rows.schema)
-        schema = v.Schema({
-            v.Required('dashboard'): dashboard,
-        })
-
-        return schema(data)
+        return dashboard
